@@ -15,7 +15,7 @@ fillCountryCode = function(country, data, outCode = "FAOST_CODE"){
   countryCODE = rep(NA, n)
   for(i in 1:n){
     ind = which(as.matrix(FAOcountryProfile[,
-      c("ABBR_FAO_NAME", "OFFICIAL_FAO_NAME", "OFFICIAL_WB_NAME", "FAO_TABLE_NAME",
+      c("OFFICIAL_FAO_NAME", "SHORT_NAME", "FAO_TABLE_NAME",
         "UNOFFICIAL1_NAME", "UNOFFICIAL2_NAME", "UNOFFICIAL3_NAME")]) ==
       unqCountry[i], arr.ind = TRUE)
     which.row = ind[, 1]
@@ -31,3 +31,5 @@ fillCountryCode = function(country, data, outCode = "FAOST_CODE"){
   colnames(def) = c(country, outCode)
   merge(x = data, y = def, by = country, all.x = TRUE)
 }
+
+utils::globalVariables(names = c("FAOcountryProfile"))
\ No newline at end of file
